@@ -266,6 +266,9 @@ clock_location_tile_fill (ClockLocationTile *this)
 	GtkWidget *align;
         GtkWidget *strut;
         GtkWidget *box;
+        GtkWidget *alignment;
+        GtkWidget *tile;
+        GtkWidget *head_section;
 	gint can_set;
 
         priv->box = gtk_event_box_new ();
@@ -278,11 +281,11 @@ clock_location_tile_fill (ClockLocationTile *this)
         g_signal_connect (priv->box, "leave-notify-event",
                           G_CALLBACK (enter_or_leave_tile), this);
 
-        GtkWidget *alignment = gtk_alignment_new (0, 0, 1, 0);
+        alignment = gtk_alignment_new (0, 0, 1, 0);
         gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 3, 3, 3, 0);
 
-        GtkWidget *tile = gtk_hbox_new (FALSE, 6);
-        GtkWidget *head_section = gtk_vbox_new (FALSE, 0);
+        tile = gtk_hbox_new (FALSE, 6);
+        head_section = gtk_vbox_new (FALSE, 0);
 
         priv->city_label = gtk_label_new (NULL);
         gtk_misc_set_alignment (GTK_MISC (priv->city_label), 0, 0);
@@ -565,13 +568,14 @@ clock_location_tile_refresh (ClockLocationTile *this, gboolean force_refresh)
 }
 
 void
-weather_info_setup_tooltip (WeatherInfo *info, GtkTooltip *tooltip)
+weather_info_setup_tooltip (WeatherInfo *info, ClockLocation *location, GtkTooltip *tooltip)
 {
         GdkPixbuf *pixbuf = NULL;
         GtkIconTheme *theme = NULL;
 	const gchar *conditions, *temp, *apparent, *wind;
 	gchar *line1, *line2, *line3, *line4, *tip;
 	const gchar *icon_name;
+	const gchar *sys_timezone;
 
        	icon_name = weather_info_get_icon_name (info);
         theme = gtk_icon_theme_get_default ();
@@ -602,9 +606,20 @@ weather_info_setup_tooltip (WeatherInfo *info, GtkTooltip *tooltip)
 	else
 		line3 = g_strdup ("");
 
+	/* FIXME: we need libgweather to give us the time,
+	 * not just a formatted string
+	 */
+	sys_timezone = getenv ("TZ");
+	setenv ("TZ", clock_location_get_timezone (location), 1);
+	tzset ();
 	line4 = g_strdup_printf (_("Sunrise: %s / Sunset: %s"),
 				 weather_info_get_sunrise (info),
 				 weather_info_get_sunset (info));
+	if (sys_timezone)
+		setenv ("TZ", sys_timezone, 1);
+	else
+		unsetenv ("TZ");
+	tzset ();
 
 	tip = g_strdup_printf ("<b>%s</b>\n%s\n%s%s", line1, line2, line3, line4);
 	gtk_tooltip_set_markup (tooltip, tip);
@@ -632,7 +647,7 @@ weather_tooltip (GtkWidget  *widget,
 	if (!info || !weather_info_is_valid (info))
 		return FALSE;
 
-	weather_info_setup_tooltip (info, tooltip);
+	weather_info_setup_tooltip (info, priv->location, tooltip);
 
 	return TRUE;
 }
